@@ -22,8 +22,8 @@ PATH0.default <- function(x, ...) {
   coord0 <- sc_coord(x)
   gmap <- gibble::gibble(x)
 
-
-  udata <- unjoin::unjoin(coord0, .data$x_, .data$y_, key_col = "vertex_")
+  ## normalize on ALL coordinate attributes, not just x_, y_ #113
+  udata <- unjoin::unjoin(coord0, names(coord0), key_col = "vertex_")
   udata[["vertex_"]]$row <- seq_len(nrow(udata[["vertex_"]]))
   #gmap <- gibble::gibble(x) %>% dplyr::mutate(path = dplyr::row_number())
   instances <- udata$data %>% dplyr::mutate(path = as.integer(factor(rep(path_paste(gmap), gmap$nrow))),
@@ -44,8 +44,12 @@ PATH0.default <- function(x, ...) {
    #handle multis
   }
   o$path_ <- split(idx, idx$object_)
+
+  ## don't select just x_, y_ #113
   vertex <- udata$vertex_ %>%
-    dplyr::arrange(.data$vertex_) %>% dplyr::select(.data$x_, .data$y_)
+    dplyr::arrange(.data$vertex_) 
+  vertex$vertex_ <- vertex$row <- NULL
+  #%>% dplyr::select(.data$x_, .data$y_)
   meta <- tibble::tibble(proj = get_projection(x), ctime = Sys.time())
   structure(list(object = o, vertex = vertex, meta = meta), class = c("PATH0", "sc"))
 }
